@@ -15,7 +15,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Hook for Mongo DB"""
+"""Hook for Mongo DB."""
 from __future__ import annotations
 
 from ssl import CERT_NONE
@@ -33,6 +33,7 @@ from airflow.typing_compat import Literal
 class MongoHook(BaseHook):
     """
     Interact with Mongo. This hook uses the Mongo conn_id.
+
     PyMongo Wrapper to Interact With Mongo Database
     Mongo Connection Documentation
     https://docs.mongodb.com/manual/reference/connection-string/index.html
@@ -75,7 +76,7 @@ class MongoHook(BaseHook):
             self.client = None
 
     def get_conn(self) -> MongoClient:
-        """Fetches PyMongo Client"""
+        """Fetches PyMongo Client."""
         if self.client is not None:
             return self.client
 
@@ -128,7 +129,8 @@ class MongoHook(BaseHook):
         self, mongo_collection: str, aggregate_query: list, mongo_db: str | None = None, **kwargs
     ) -> pymongo.command_cursor.CommandCursor:
         """
-        Runs an aggregation pipeline and returns the results
+        Runs an aggregation pipeline and returns the results.
+
         https://pymongo.readthedocs.io/en/stable/api/pymongo/collection.html#pymongo.collection.Collection.aggregate
         https://pymongo.readthedocs.io/en/stable/examples/aggregation.html
         """
@@ -170,7 +172,8 @@ class MongoHook(BaseHook):
         **kwargs,
     ) -> pymongo.cursor.Cursor | Any | None:
         """
-        Runs a mongo find query and returns the results
+        Runs a mongo find query and returns the results.
+
         https://pymongo.readthedocs.io/en/stable/api/pymongo/collection.html#pymongo.collection.Collection.find
         """
         collection = self.get_collection(mongo_collection, mongo_db=mongo_db)
@@ -184,7 +187,8 @@ class MongoHook(BaseHook):
         self, mongo_collection: str, doc: dict, mongo_db: str | None = None, **kwargs
     ) -> pymongo.results.InsertOneResult:
         """
-        Inserts a single document into a mongo collection
+        Inserts a single document into a mongo collection.
+
         https://pymongo.readthedocs.io/en/stable/api/pymongo/collection.html#pymongo.collection.Collection.insert_one
         """
         collection = self.get_collection(mongo_collection, mongo_db=mongo_db)
@@ -196,6 +200,7 @@ class MongoHook(BaseHook):
     ) -> pymongo.results.InsertManyResult:
         """
         Inserts many docs into a mongo collection.
+
         https://pymongo.readthedocs.io/en/stable/api/pymongo/collection.html#pymongo.collection.Collection.insert_many
         """
         collection = self.get_collection(mongo_collection, mongo_db=mongo_db)
@@ -212,6 +217,7 @@ class MongoHook(BaseHook):
     ) -> pymongo.results.UpdateResult:
         """
         Updates a single document in a mongo collection.
+
         https://pymongo.readthedocs.io/en/stable/api/pymongo/collection.html#pymongo.collection.Collection.update_one
 
         :param mongo_collection: The name of the collection to update.
@@ -235,6 +241,7 @@ class MongoHook(BaseHook):
     ) -> pymongo.results.UpdateResult:
         """
         Updates one or more documents in a mongo collection.
+
         https://pymongo.readthedocs.io/en/stable/api/pymongo/collection.html#pymongo.collection.Collection.update_many
 
         :param mongo_collection: The name of the collection to update.
@@ -257,6 +264,7 @@ class MongoHook(BaseHook):
     ) -> pymongo.results.UpdateResult:
         """
         Replaces a single document in a mongo collection.
+
         https://pymongo.readthedocs.io/en/stable/api/pymongo/collection.html#pymongo.collection.Collection.replace_one
 
         .. note::
@@ -326,6 +334,7 @@ class MongoHook(BaseHook):
     ) -> pymongo.results.DeleteResult:
         """
         Deletes a single document in a mongo collection.
+
         https://pymongo.readthedocs.io/en/stable/api/pymongo/collection.html#pymongo.collection.Collection.delete_one
 
         :param mongo_collection: The name of the collection to delete from.
@@ -342,6 +351,7 @@ class MongoHook(BaseHook):
     ) -> pymongo.results.DeleteResult:
         """
         Deletes one or more documents in a mongo collection.
+
         https://pymongo.readthedocs.io/en/stable/api/pymongo/collection.html#pymongo.collection.Collection.delete_many
 
         :param mongo_collection: The name of the collection to delete from.
